import setuptools

import accu

setuptools.setup(
    name='accu',
    version=accu.__version__,
    url='https://github.com/mohanson/python-accu',
    license='PSF',
    author='mohanson',
    author_email='mohanson@outlook.com',
    description='accu',
    packages=['accu'],
    install_requires=[
    ]
)
